@@ -17,9 +17,10 @@ from sparknlp.common import *
 
 
 class SpanBertCorefModel(AnnotatorModel,
-                     HasEmbeddingsProperties,
-                     HasCaseSensitiveProperties,
-                     HasStorageRef):
+                         HasEmbeddingsProperties,
+                         HasCaseSensitiveProperties,
+                         HasStorageRef,
+                         HasEngine):
     """
     A coreference resolution model based on SpanBert.
 
@@ -115,14 +116,14 @@ class SpanBertCorefModel(AnnotatorModel,
                               typeConverter=TypeConverters.toInt)
 
     maxSegmentLength = Param(Params._dummy(),
-                              "maxSegmentLength",
-                              "Max segment length",
-                              typeConverter=TypeConverters.toInt)
+                             "maxSegmentLength",
+                             "Max segment length",
+                             typeConverter=TypeConverters.toInt)
 
     textGenre = Param(Params._dummy(),
-                             "textGenre",
-                             "Text genre, one of ('bc', 'bn', 'mz', 'nw', 'pt','tc', 'wb')",
-                             typeConverter=TypeConverters.toString)
+                      "textGenre",
+                      "Text genre, one of ('bc', 'bn', 'mz', 'nw', 'pt','tc', 'wb')",
+                      typeConverter=TypeConverters.toString)
 
     configProtoBytes = Param(Params._dummy(),
                              "configProtoBytes",
@@ -228,4 +229,3 @@ class SpanBertCorefModel(AnnotatorModel,
         """
         from sparknlp.pretrained import ResourceDownloader
         return ResourceDownloader.downloadModel(SpanBertCorefModel, name, lang, remote_loc)
-
